@@ -10,7 +10,7 @@ from vorta.borg.borg_thread import BorgThread
 from vorta.borg.create import BorgCreateThread
 from vorta.borg.version import BorgVersionThread
 from vorta.borg.break_lock import BorgBreakThread
-from vorta.config import TEMP_DIR
+from vorta.config import TEMP_DIR, PROFILE_BOOTSTRAP_FILE
 from vorta.i18n import init_translations, translate
 from vorta.models import BackupProfileModel, SettingsModel, cleanup_db
 from vorta.qt_single_application import QtSingleApplication
@@ -19,6 +19,7 @@ from vorta.tray_menu import TrayMenu
 from vorta.utils import borg_compat, parse_args
 from vorta.views.main_window import MainWindow
 from vorta.notifications import VortaNotifications
+from vorta.profile_export import ProfileExport
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +41,6 @@ class VortaApp(QtSingleApplication):
     backup_progress_event = QtCore.pyqtSignal(str)
 
     def __init__(self, args_raw, single_app=False):
-
         super().__init__(APP_ID, args_raw)
         args = parse_args()
         if self.isRunning():
@@ -61,6 +61,9 @@ class VortaApp(QtSingleApplication):
         self.scheduler = VortaScheduler(self)
         self.setApplicationName("Vorta")
 
+        # Import profile from ~/.vorta-init.json or add empty "Default" profile.
+        self.bootstrap_profile()
+
         # Prepare tray and main window
         self.tray = TrayMenu(self)
         self.main_window = MainWindow(self)
@@ -75,8 +78,11 @@ class VortaApp(QtSingleApplication):
         self.backup_cancelled_event.connect(self.backup_cancelled_event_response)
         self.message_received_event.connect(self.message_received_event_response)
         self.backup_log_event.connect(self.react_to_log)
-        self.aboutToQuit.connect(cleanup_db)
+        self.aboutToQuit.connect(self.quit_app_action)
         self.set_borg_details_action()
+        if sys.platform == 'darwin':
+            self.check_darwin_permissions()
+
         self.installEventFilter(self)
 
     def create_backups_cmdline(self, profile_name):
@@ -101,6 +107,14 @@ class VortaApp(QtSingleApplication):
             self.tray.set_tray_icon()
         return False
 
+    def quit_app_action(self):
+        self.backup_cancelled_event.emit()
+        self.scheduler.shutdown()
+        del self.main_window
+        self.tray.deleteLater()
+        del self.tray
+        cleanup_db()
+
     def create_backup_action(self, profile_id=None):
         if not profile_id:
             profile_id = self.main_window.current_profile.id
@@ -174,6 +188,30 @@ class VortaApp(QtSingleApplication):
         msg.setStandardButtons(QMessageBox.Ok)
         msg.exec()
 
+    def check_darwin_permissions(self):
+        """
+        macOS restricts access to certain folders by default. For some folders, the user
+        will get a prompt (e.g. Documents, Downloads), while others will cause file access
+        errors.
+
+        This function tries reading a file that is known to be restricted and warn the user about
+        incomplete backups.
+        """
+        test_path = os.path.expanduser('~/Library/Cookies')
+        if os.path.exists(test_path) and not os.access(test_path, os.R_OK):
+            msg = QMessageBox()
+            msg.setIcon(QMessageBox.Warning)
+            msg.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse)
+            msg.setText(self.tr("Vorta needs Full Disk Access for complete Backups"))
+            msg.setInformativeText(self.tr(
+                "Without this, some files won't be accessible and you may end up with an incomplete "
+                "backup. Please set <b>Full Disk Access</b> permission for Vorta in "
+                "<a href='x-apple.systempreferences:com.apple.preference.security?Privacy'>"
+                "System Preferences > Security & Privacy</a>."
+            ))
+            msg.setStandardButtons(QMessageBox.Ok)
+            msg.exec()
+
     def react_to_log(self, mgs, context):
         """
         Trigger Vorta actions based on Borg logs. E.g. repo lock.
@@ -190,7 +228,7 @@ class VortaApp(QtSingleApplication):
             msg.setDefaultButton(abortButton)
             msg.setText(self.tr(f"The repository at {repo_url} might be in use elsewhere."))
             msg.setInformativeText(self.tr("Only break the lock if you are certain no other Borg process "
-                                   "on any machine is accessing the repository. Abort or break the lock?"))
+                                           "on any machine is accessing the repository. Abort or break the lock?"))
             msg.accepted.connect(lambda: self.break_lock(profile))
             self._msg = msg
             msg.show()
@@ -207,7 +245,26 @@ class VortaApp(QtSingleApplication):
     def break_lock(self, profile):
         params = BorgBreakThread.prepare(profile)
         if not params['ok']:
-            self.set_progress(params['message'])
+            self.backup_progress_event.emit(params['message'])
             return
         thread = BorgBreakThread(params['cmd'], params, parent=self)
         thread.start()
+
+    def bootstrap_profile(self, bootstrap_file=PROFILE_BOOTSTRAP_FILE):
+        """
+        Make sure there is at least one profile when first starting Vorta.
+        Will either import a profile placed in ~/.vorta-init.json
+        or add an empty "Default" profile.
+        """
+        if bootstrap_file.is_file():
+            profile_export = ProfileExport.from_json(bootstrap_file)
+            profile = profile_export.to_db(overwrite_profile=True, overwrite_settings=True)
+            bootstrap_file.unlink()
+            notifier = VortaNotifications.pick()
+            notifier.deliver(self.tr('Profile import successful!'),
+                             self.tr('Profile {} imported.').format(profile.name),
+                             level='info')
+            logger.info('Profile {} imported.'.format(profile.name))
+        if BackupProfileModel.select().count() == 0:
+            default_profile = BackupProfileModel(name='Default')
+            default_profile.save()
