@@ -1,13 +1,11 @@
 import argparse
 import errno
 import getpass
-import operator
 import os
 import platform
 import re
 import sys
 import unicodedata
-from collections import defaultdict
 from datetime import datetime as dt
 from functools import reduce
 
@@ -22,7 +20,6 @@ from PyQt5.QtWidgets import QApplication, QFileDialog, QSystemTrayIcon
 
 from vorta.borg._compatibility import BorgCompatibility
 from vorta.i18n import trans_late
-from vorta.keyring.abc import VortaKeyring
 from vorta.log import logger
 from vorta.network_status.abc import NetworkStatusMonitor
 
@@ -62,12 +59,13 @@ def get_directory_size(dir_path):
             if os.path.islink(file_path):
                 continue
 
-            stat = os.stat(file_path)
-
-            # Visit each file once
-            if stat.st_ino not in seen:
-                seen.add(stat.st_ino)
-                data_size += stat.st_size
+            try:
+                stat = os.stat(file_path)
+                if stat.st_ino not in seen:  # Visit each file only once
+                    seen.add(stat.st_ino)
+                    data_size += stat.st_size
+            except (FileNotFoundError, PermissionError):
+                continue
 
     files_count = len(seen)
 
@@ -105,11 +103,11 @@ def nested_dict():
     - https://stackoverflow.com/a/16724937/3983708
     - https://stackoverflow.com/a/14692747/3983708
     """
-    return defaultdict(nested_dict)
+    return dict()
 
 
 def get_dict_from_list(dataDict, mapList):
-    return reduce(operator.getitem, mapList, dataDict)
+    return reduce(lambda d, k: d.setdefault(k, {}), mapList, dataDict)
 
 
 def choose_file_dialog(parent, title, want_folder=True):
@@ -169,20 +167,19 @@ def sort_sizes(size_list):
     return final_list
 
 
-def pretty_bytes(size):
-    """from https://stackoverflow.com/questions/12523586/
-            python-format-size-application-converting-b-to-kb-mb-gb-tb/37423778"""
+def pretty_bytes(size, metric=True, sign=False, precision=1):
     if not isinstance(size, int):
         return ''
-    power = 1000  # GiB is base 2**10, GB is base 10**3.
+    prefix = '+' if sign and size > 0 else ''
+    power, units = (10**3, ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y']) if metric else \
+                   (2**10, ['', 'Ki', 'Mi', 'Gi', 'Ti', 'Pi', 'Ei', 'Zi', 'Yi'])
     n = 0
-    Dic_powerN = {0: '', 1: 'K', 2: 'M', 3: 'G', 4: 'T'}
-    while size >= power:
+    while abs(round(size, precision)) >= power and n + 1 < len(units):
         size /= power
         n += 1
     try:
-        unit = Dic_powerN[n]
-        return f'{round(size, 1)} {unit}B'
+        unit = units[n]
+        return f'{prefix}{round(size, precision)} {unit}B'
     except KeyError as e:
         logger.error(e)
         return "NaN"
@@ -336,14 +333,3 @@ def validate_passwords(first_pass, second_pass):
         return trans_late('utils', "Passwords must be greater than 8 characters long.")
 
     return ""
-
-
-def display_password_backend(encryption):
-    ''' Display password backend message based off current keyring '''
-    # flake8: noqa E501
-    if encryption != 'none':
-        keyring = VortaKeyring.get_keyring()
-        return trans_late('utils', "Storing the password in your password manager.") if keyring.is_primary else trans_late(
-            'utils', 'Saving the password to disk. To store password more securely install a supported secret store such as KeepassXC')
-    else:
-        return ""
