@@ -14,6 +14,7 @@ from vorta.borg.diff import BorgDiffThread
 from vorta.borg.extract import BorgExtractThread
 from vorta.borg.list_archive import BorgListArchiveThread
 from vorta.borg.list_repo import BorgListRepoThread
+from vorta.borg.info_archive import BorgInfoArchiveThread
 from vorta.borg.mount import BorgMountThread
 from vorta.borg.prune import BorgPruneThread
 from vorta.borg.umount import BorgUmountThread
@@ -117,10 +118,6 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             action.setEnabled(False)
             return menu
 
-        extractAction = menu.addAction("Extract", self.list_archive_action)
-        deleteAction = menu.addAction("Delete", self.delete_action)
-        renameAction = menu.addAction("Rename", self.rename_action)
-
         if archive_name in self.mount_points:
             unmountAction = menu.addAction("Unmount", self.umount_action)
             unmountAction.setIcon(get_colored_icon('eject'))
@@ -128,9 +125,15 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             mountAction = menu.addAction("Mount", self.mount_action)
             mountAction.setIcon(get_colored_icon('folder-open'))
 
+        extractAction = menu.addAction("Extract", self.list_archive_action)
+        refreshAction = menu.addAction("Refresh", self.refresh_archive_action)
+        renameAction = menu.addAction("Rename", self.rename_action)
+        deleteAction = menu.addAction("Delete", self.delete_action)
+
         extractAction.setIcon(get_colored_icon('cloud-download'))
-        deleteAction.setIcon(get_colored_icon('trash'))
+        refreshAction.setIcon(get_colored_icon('refresh'))
         renameAction.setIcon(get_colored_icon('edit'))
+        deleteAction.setIcon(get_colored_icon('trash'))
         return menu
 
     def populate_from_profile(self):
@@ -258,6 +261,23 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self._set_status(self.tr('Refreshed archives.'))
             self.populate_from_profile()
 
+    def refresh_archive_action(self):
+        archive_name = self.selected_archive_name()
+        if archive_name is not None:
+            params = BorgInfoArchiveThread.prepare(self.profile(), archive_name)
+            if params['ok']:
+                thread = BorgInfoArchiveThread(params['cmd'], params, parent=self.app)
+                thread.updated.connect(self._set_status)
+                thread.result.connect(self.refresh_archive_result)
+                self._toggle_all_buttons(False)
+                thread.start()
+
+    def refresh_archive_result(self, result):
+        self._toggle_all_buttons(True)
+        if result['returncode'] == 0:
+            self._set_status(self.tr('Refreshed archive.'))
+            self.populate_from_profile()
+
     def selected_archive_name(self):
         row_selected = self.archiveTable.selectionModel().selectedRows()
         if row_selected:
@@ -356,13 +376,11 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             archive_cell = self.archiveTable.item(row_selected[0].row(), 4)
             if archive_cell:
                 archive_name = archive_cell.text()
-                params = BorgListArchiveThread.prepare(profile)
+                params = BorgListArchiveThread.prepare(profile, archive_name)
 
                 if not params['ok']:
                     self._set_status(params['message'])
                     return
-                params['cmd'][-1] += f'::{archive_name}'
-                params['archive_name'] = archive_name
                 self._set_status('')
                 self._toggle_all_buttons(False)
 
@@ -473,8 +491,6 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 archive_name_older = archive_cell_older.text()
 
                 params = BorgDiffThread.prepare(profile, archive_name_older, archive_name_newer)
-                params['archive_name_newer'] = archive_name_newer
-                params['archive_name_older'] = archive_name_older
 
                 if params['ok']:
                     self._toggle_all_buttons(False)
@@ -499,7 +515,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         if result['returncode'] == 0:
             archive_newer = ArchiveModel.get(name=result['params']['archive_name_newer'])
             archive_older = ArchiveModel.get(name=result['params']['archive_name_older'])
-            window = DiffResult(result['data'], archive_newer, archive_older)
+            window = DiffResult(result['data'], archive_newer, archive_older, result['params']['json_lines'])
             self._toggle_all_buttons(True)
             window.setParent(self, QtCore.Qt.Sheet)
             self._resultwindow = window  # for testing
